Crate tracing_perfetto_sdk_sys

Crate tracing_perfetto_sdk_sys 

tracing-perfetto-sdk-sys: C++ bindings to the raw Perfetto SDK

This crate only contains low-level bindings to the C++ library. While the interface is safe, it is recommended to use a higher level API, for example via the tracing-perfetto-sdk-layer crate.

Modules

ffi
FFI bridge: Definitions of functions and types that are shared across the C++ boundary.

Structs

FlushCtx
A context that will be passed-in in a call to [ffi::flush] and later passed back in the done callback when the async operation has completed.
PollTracesCtx
A context that will be passed-in in a call to [ffi::poll_traces] and later passed back in the done callback when the async operation has completed.
PolledTraces
Traces returned from poll_traces/the channel returned by PollTracesCtx::new.